@@ -82,11 +82,7 @@ use hashbrown::hash_table::{Entry, VacantEntry};
 /// # }
 /// ```
 #[derive(Clone)]
-pub struct TriHashMap<
-    T: TriHashItem,
-    S = DefaultHashBuilder,
-    A: Allocator = Global,
-> {
+pub struct TriHashMap<T, S = DefaultHashBuilder, A: Allocator = Global> {
     pub(super) items: ItemSet<T, A>,
     // Invariant: the values (usize) in these tables are valid indexes into
     // `items`, and are a 1:1 mapping.
@@ -146,7 +142,7 @@ impl<T: TriHashItem> TriHashMap<T> {
     /// ```
     #[inline]
     pub fn new() -> Self {
-        Self { items: ItemSet::default(), tables: TriHashMapTables::default() }
+        Self { items: ItemSet::new(), tables: TriHashMapTables::default() }
     }
 
     /// Creates a new `TriHashMap` with the given capacity.
@@ -239,7 +235,7 @@ impl<T: TriHashItem, S: Clone + BuildHasher> TriHashMap<T, S> {
     /// ```
     pub fn with_hasher(hasher: S) -> Self {
         Self {
-            items: ItemSet::default(),
+            items: ItemSet::new(),
             tables: TriHashMapTables::with_capacity_and_hasher_in(
                 0,
                 hasher.clone(),
